@@ -502,7 +502,7 @@ class Demo:
         hv.extension('bokeh', logo=False)
 
         if datadir is None:
-            self.datadir = _my_path.parent / 'data'
+            self.datadir = _my_path / 'data'
         else:
             self.datadir = Path(datadir)
 
@@ -628,11 +628,11 @@ class Demo:
         gspec = pn.GridSpec(sizing_mode='stretch_both')
         # gspec[0, 0:5] = pn.pane.Markdown('# Instance Hardness dashboard demo', style={'color': '#1A76FF'})
         # gspec[0, 4] = pn.pane.JPG(str(_my_path.parent / 'docs/img/ita_rgb.jpg'), width=100)
-        gspec[0:3, 0] = pn.WidgetBox('<h5>' + md_color.format('Dataset') + '</h5>', self.w_dir,
-                                     '<h6>' + md_color.format('Dimensionality Reduction') + '</h6>', self.w_dim,
+        gspec[0:3, 0] = pn.WidgetBox('## Dataset', self.w_dir,
+                                     '### Dimensionality Reduction', self.w_dim,
                                      pn.Row(pn.Spacer(), height=20))
-        gspec[3:7, 0] = pn.WidgetBox('<h5>' + md_color.format('Color') + '</h5>', self.w_color,
-                                     '<h6>' + md_color.format('Color Bar') + '</h6>', self.w_checkbox,
+        gspec[3:7, 0] = pn.WidgetBox('## Color', self.w_color,
+                                     '### Color Bar', self.w_checkbox,
                                      self.w_color_range,
                                      pn.Row(pn.Spacer(), height=20))
         gspec[0:7, 1:5] = dmap
